<?php

class ModuleFrontPage extends AppModule
{
  function __construct($System)
  {
    parent::__construct($System);
    $this->Name = 'FrontPage';
    $this->Version = '1.0';
    $this->Creator = 'Chronos';
    $this->License = 'GNU/GPL';
    $this->Description = 'Main welcome page';
    $this->Dependencies = array('News', 'User', 'ShoutBox', 'Translation');
  }
  
  function Start()
  {
    $this->System->RegisterPage('', 'PageFrontPage');
    $this->System->RegisterMenuItem(array(
      'Title' => 'Domů',
      'Hint' => 'Hlavní stránka', 
      'Link' => $this->System->Link('/'),
      'Permission' => LICENCE_ANONYMOUS,
      'Icon' => '', 
    ), 0);
  }
  
  function HandleLoginForm()
  {
  	global $User, $Message, $MessageType;
  
  	if(array_key_exists('action', $_GET))
  	{
  		if($_GET['action'] == 'login')
  		{
  			if(array_key_exists('LoginUser', $_POST) and array_key_exists('LoginPass', $_POST))
  			{
  				$User->Login($_POST['LoginUser'], $_POST['LoginPass']);
  				if($User->Role == LICENCE_ANONYMOUS)
  				{
  					$Message = 'Jméno nebo heslo bylo zadáno špatně.';
  					$MessageType = MESSAGE_CRITICAL;
  				} else
  				{
  					$Message = 'Přihlášení proběhlo úspěšně. Vítej <strong>'.$User->Name.'</strong>!';
  					$MessageType = MESSAGE_INFORMATION;
  				}
  			} else
  			{
  				$Message = 'Nebylo zadáno jméno a heslo.';
  				$MessageType = MESSAGE_CRITICAL;
  			}
  		} else
  			if($_GET['action'] == 'logout')
  			{
  				if($User->Role != LICENCE_ANONYMOUS)
  				{
  					WriteLog('Odhlášení', LOG_TYPE_USER);
  					$User->Logout();
  					$Message = 'Byl jsi odhlášen.';
  					$MessageType = MESSAGE_INFORMATION;
  				}
  			}
  	}
  }  
}

class PageFrontPage extends Page
{
  function Show()
  {
  	global $Message, $MessageType;
  	
  	$this->System->ModuleManager->Modules['FrontPage']->HandleLoginForm();
  	$Output = '';
  	if(isset($Message)) $Output .= ShowMessage($Message, $MessageType);
  	 
  	$Output .= '<br />'.
  			'<table class="Home"><tr><td colspan="3">'.$this->ShowWelcome().
  			'</td></tr>'.
  			'<tr><td>'.$this->ShowLastTranslated().'</td>'.
  			'<td class="news-box">'.$this->System->ModuleManager->Modules['News']->ShowBox().'</td>'.
  			'<td>'.$this->System->ModuleManager->Modules['ShoutBox']->ShowBox().'</td>'.
  			'</tr></table>';
  	 return($Output);
  }  
  
  function ShowLastTranslated()
  {
  	$Count = 40;
  	$Output = '<strong>Poslední překlady:</strong>';
  
  	$GroupListQuery = 'SELECT `Group`.* FROM `Group`';
  	$Query = '';
  	$UnionItems = array();
  	$DbResult = $this->Database->query($GroupListQuery);
  	if($DbResult->num_rows > 0)
  	{
  		while($DbRow = $DbResult->fetch_assoc())
  		{
  			$UnionItems[] = 'SELECT `T`.`ID`, `T`.`Take`, `T`.`User`, `T`.`ModifyTime`, `T`.`Group`, `T`.`GroupName` '.
  					'FROM (SELECT `T`.`User`, `T`.`ID`, `T`.`ModifyTime`, '.
  					$DbRow['Id'].' AS `Group`, "'.addslashes($DbRow['Name']).'" AS `GroupName`, `T`.`Take` FROM `'.
  					$DbRow['TablePrefix'].'` AS `T`'.
  					' WHERE (`T`.`Complete` = 1) AND (`T`.`Language` != '.$this->System->Config['OriginalLanguage'].') ORDER BY `T`.`ModifyTime` DESC LIMIT '.
  					$Count.') AS `T`';
  		}
  		$Query = 'SELECT `TT`.*, `User`.`Name` AS `UserName`, `User`.`Id` AS `UserId` '.
  				' FROM ('.implode(' UNION ', $UnionItems).') AS `TT`'.
  				' JOIN `User` ON `User`.`Id` = `TT`.`User`'.
  				' ORDER BY `ModifyTime` DESC LIMIT '.$Count;
  		$DbResult = $this->Database->query($Query);
  		$Output .= '<table class="MiniTable"><tr><th>Datum</th><th>Kdo</th><th>Nový</th><th>Zdroj</th><th>Skupina</th></tr>';
  		while($DbRow = $DbResult->fetch_assoc())
  		{
  			$Output .= '<tr><td>'.HumanDate($DbRow['ModifyTime']).'</td>'.
  					'<td><a href="user.php?user='.$DbRow['UserId'].'">'.$DbRow['UserName'].'</a></td>'.
  					'<td><a href="form.php?group='.$DbRow['Group'].'&amp;ID='.$DbRow['ID'].'">'.$DbRow['ID'].'</a></td>'.
  					'<td><a href="form.php?group='.$DbRow['Group'].'&amp;ID='.$DbRow['Take'].'">'.$DbRow['Take'].'</a></td>'.
  					'<td><a href="TranslationList.php?group='.$DbRow['Group'].'&amp;action=filter">'.$DbRow['GroupName'].'</a></td></tr>';
  		}
  		$Output .= '</table>';
  	}
  	return($Output);
  }

  function ShowWelcome()
  {
  	// Cookies have to be used before any text is sent to output
  	if(!array_key_exists('HideWelcome', $_COOKIE)) $_COOKIE['HideWelcome'] = 0;
  	if(isset($_GET['Action']))
  	{
  		if($_GET['Action'] == 'HideWelcome') $_COOKIE['HideWelcome'] = 1;
  		if($_GET['Action'] == 'UnHideWelcome') $_COOKIE['HideWelcome'] = 0;
  	}
  	setcookie('HideWelcome', $_COOKIE['HideWelcome'], time() + 3600 * 24 * 365);
  
  	if(isset($_COOKIE['HideWelcome']) and ($_COOKIE['HideWelcome'] == 1))
  	{
  		$Action = '<a href="?Action=UnHideWelcome">Odkrýt úvod</a>';
  		$HideWelcome = 'display: none';
  	} else
  	{
  		$Action = '<a href="?Action=HideWelcome">Skrýt úvod</a>';
  		$HideWelcome = '';
  	}
  
  	// Echo text even if it is hidden because of caching by external searching engines
  	return('<div style="'.$HideWelcome.'">'.
  			'<div id="bannertitle">'.$this->System->Config['Web']['Title'].'</div>'.
  			'Otevřený webový systém pro překládání textů ze hry World of Warcraft (WoW).<br />'.
  			'<ul>'.
  			'<li>Projekt je provozován jako otevřený vyznává principy volnosti a otevřenosti. Proto jsou texty volně ke stažení.</li>'.
  			'<li>Projekt slouží k týmovému překladu. Kdokoliv může přispět přeložením textů a uveřejněním odkazu popř. banneru na svých stránkách.</li>'.
  			'<li>Projekt není zaměřen pouze na jeden server a umožňuje společné překládání lidem z různých serverů. Překladatelé mohou překládat v týmech podle jména svého serveru a exportovat texty pouze od vybraných překladatelů.</li>'.
  			'<li>Přeložené texty lze volně stahovat v různých tvarech jako XML, SQL, Addon a Lua. Přeložené texty lze tedy snadno importovat do svého free serveru nebo použít v jiných projektech.</li>'.
  			'<li>Cílem projektu je přeložit všechny texty ze hry. Nikoliv pouze texty výprav (questů).</li>'.
  			'<li>Texty lze překládat do dvou jazyků, češtiny a slovenštiny.</li>'.
  			'</ul></div>'.$Action);
  }  
}
